@@ -407,31 +407,16 @@ namespace msXpSmineXpert
 					mainWindow->mp_massSpecWnd,
 					&MassSpecWnd::newMassSpectrum);
 
-			connect(static_cast<ColorMapPlotWidget *>(widget),
-					&ColorMapPlotWidget::jsNewMassSpectrum,
-					mainWindow->mp_massSpecWnd,
-					&MassSpecWnd::jsNewMassSpectrum);
-
 			connect(static_cast<ColorMapPlotWidget *>(widget),
 					&ColorMapPlotWidget::newDriftSpectrum,
 					mainWindow->mp_driftSpecWnd,
 					&DriftSpecWnd::newDriftSpectrum);
 
-			connect(static_cast<ColorMapPlotWidget *>(widget),
-					&ColorMapPlotWidget::jsNewDriftSpectrum,
-					mainWindow->mp_driftSpecWnd,
-					&DriftSpecWnd::jsNewDriftSpectrum);
-
 			connect(static_cast<ColorMapPlotWidget *>(widget),
 					&ColorMapPlotWidget::newTicChromatogram,
 					mainWindow->mp_ticChromWnd,
 					&TicChromWnd::newTicChromatogram);
 
-			connect(static_cast<ColorMapPlotWidget *>(widget),
-					&ColorMapPlotWidget::jsNewTicChromatogram,
-					mainWindow->mp_ticChromWnd,
-					&TicChromWnd::jsNewTicChromatogram);
-
 			connect(static_cast<ColorMapPlotWidget *>(widget),
 					&ColorMapPlotWidget::ticIntensitySignal,
 					this,
