@@ -93,8 +93,8 @@ namespace msXpSmineXpert
 				.arg((quintptr)this, QT_POINTER_SIZE * 2, 16, QChar('0'));
 
 			text += QString("%1: 0x%2 --")
-				.arg("mp_dataSet")
-				.arg((quintptr)mp_dataSet, QT_POINTER_SIZE * 2, 16, QChar('0'));
+				.arg("mp_massSpecDataSet")
+				.arg((quintptr)mp_massSpecDataSet, QT_POINTER_SIZE * 2, 16, QChar('0'));
 
 			text += QString("%1: 0x%2 --")
 				.arg("mp_originPlotWidget")
@@ -154,7 +154,7 @@ namespace msXpSmineXpert
 	//! Allocate a new DataPlotWidgetRelation and append it to \c this instance.
 	/*!
 
-		\param dataSet pointer to the MassSpecDataSet instance storing all the mass
+		\param massSpecDataSet pointer to the MassSpecDataSet instance storing all the mass
 		data. Cannot be Q_NULLPTR.
 
 		\param orig origin plot widget. Can be Q_NULLPTR if the relation is to
@@ -170,30 +170,30 @@ namespace msXpSmineXpert
 
 */
 	void
-		DataPlotWidgetRelationer::newRelation(MassSpecDataSet * dataSet,
+		DataPlotWidgetRelationer::newRelation(const MassSpecDataSet *massSpecDataSet,
 				AbstractPlotWidget *orig,
 				AbstractPlotWidget *target,
-				QListWidgetItem * widgetItem)
+				QListWidgetItem *widgetItem)
 		{
 			// Only two data members cannot be Q_NULLPTR when calling this function:
-			if(dataSet == Q_NULLPTR || target == Q_NULLPTR)
+			if(massSpecDataSet == Q_NULLPTR || target == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			DataPlotWidgetRelation *p_relation = new DataPlotWidgetRelation;
 
-			p_relation->mp_dataSet = dataSet;
+			p_relation->mp_massSpecDataSet = massSpecDataSet;
 			p_relation->mp_originPlotWidget = orig;
 			p_relation->mp_targetPlotWidget = target;
 			p_relation->mp_openSpectraListWidgetItem = widgetItem;
 
 			//QString msg =
 			//QString("New relation: 0x%1\n"
-			//"\tdataSet: 0x%2\n"
+			//"\tmassSpecDataSet: 0x%2\n"
 			//"\torigin plot widget: 0x%3\n"
 			//"\ttarget plot widget: 0x%4\n"
 			//"\ttarget name: %5\n")
 			//.arg((quintptr)p_relation, QT_POINTER_SIZE * 2, 16, QChar('0'))
-			//.arg((quintptr)p_relation->mp_dataSet, QT_POINTER_SIZE * 2, 16, QChar('0'))
+			//.arg((quintptr)p_relation->mp_massSpecDataSet, QT_POINTER_SIZE * 2, 16, QChar('0'))
 			//.arg((quintptr)p_relation->mp_originPlotWidget, QT_POINTER_SIZE * 2, 16, QChar('0'))
 			//.arg((quintptr)p_relation->mp_targetPlotWidget, QT_POINTER_SIZE * 2, 16, QChar('0'))
 			//.arg(target->desc());
@@ -208,11 +208,11 @@ namespace msXpSmineXpert
 	// Returns true if the relation was updated and false if a new one was added.
 
 	bool
-		DataPlotWidgetRelationer::updateOrAddRelation(MassSpecDataSet *dataSet,
+		DataPlotWidgetRelationer::updateOrAddRelation(MassSpecDataSet *massSpecDataSet,
 				AbstractPlotWidget *origin,
 				AbstractPlotWidget *target,
 				QListWidgetItem *widgetItem) {
-			if (dataSet == Q_NULLPTR || origin == Q_NULLPTR || target == Q_NULLPTR)
+			if (massSpecDataSet == Q_NULLPTR || origin == Q_NULLPTR || target == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.",
 						__FILE__, __LINE__);
 
@@ -228,7 +228,7 @@ namespace msXpSmineXpert
 				// there won't be any relation object that has its target pointer with
 				// value Q_NULLPTR, which means we have to actually duplicate the found
 				// object and fill-in the target value.
-				if (p_relation->mp_dataSet == dataSet &&
+				if (p_relation->mp_massSpecDataSet == massSpecDataSet &&
 						p_relation->mp_originPlotWidget == origin &&
 						p_relation->mp_targetPlotWidget == Q_NULLPTR) {
 					if (widgetItem != Q_NULLPTR) {
@@ -248,7 +248,7 @@ namespace msXpSmineXpert
 			// First, we need to get a pointer to the QListWidgetItem.
 			QListWidgetItem *item = listWidgetItem(origin);
 
-			newRelation(dataSet, origin, target, item);
+			newRelation(massSpecDataSet, origin, target, item);
 
 			return false;
 		}
@@ -428,14 +428,14 @@ namespace msXpSmineXpert
 		}
 
 
-	//! Get all the relations the have \p dataSet as the data set member.
+	//! Get all the relations the have \p massSpecDataSet as the data set member.
 	/*!
 
 		The member list of DataPlotWidgetRelation instances is iterated in and for
-		each DataPlotWidgetRelation instance having \c mp_dataSet identical
-		to \p dataSet, append that instance to \p list.
+		each DataPlotWidgetRelation instance having \c mp_massSpecDataSet identical
+		to \p massSpecDataSet, append that instance to \p list.
 
-		\param dataSet dataSet to be searched for. Cannot be Q_NULLPTR.
+		\param massSpecDataSet massSpecDataSet to be searched for. Cannot be Q_NULLPTR.
 
 		\param list list in which to append all the found relations. Cannot be Q_NULLPTR.
 
@@ -446,16 +446,16 @@ namespace msXpSmineXpert
 */
 	void
 		DataPlotWidgetRelationer::getRelationsByData(
-				MassSpecDataSet *dataSet, QList<DataPlotWidgetRelation *> *list)
+				const MassSpecDataSet *massSpecDataSet, QList<DataPlotWidgetRelation *> *list)
 		{
-			if(dataSet == Q_NULLPTR || list == Q_NULLPTR)
+			if(massSpecDataSet == Q_NULLPTR || list == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			for(int iter = 0; iter < m_relationList.size(); ++iter)
 			{
 				DataPlotWidgetRelation *p_relation = m_relationList.at(iter);
 
-				if(p_relation->mp_dataSet == dataSet)
+				if(p_relation->mp_massSpecDataSet == massSpecDataSet)
 					list->append(p_relation);
 			}
 		}
@@ -506,13 +506,13 @@ namespace msXpSmineXpert
 		}
 
 	AbstractPlotWidget *
-		DataPlotWidgetRelationer::origin(MassSpecDataSet *dataSet)
+		DataPlotWidgetRelationer::origin(const MassSpecDataSet *massSpecDataSet)
 		{
 			for(int iter = 0; iter < m_relationList.size(); ++iter)
 			{
 				DataPlotWidgetRelation *p_relation = m_relationList.at(iter);
 
-				if(p_relation->mp_dataSet == dataSet)
+				if(p_relation->mp_massSpecDataSet == massSpecDataSet)
 					return p_relation->mp_originPlotWidget;
 			}
 
@@ -778,11 +778,11 @@ namespace msXpSmineXpert
 
 						QString msg =
 							QString("Deleting relation: 0x%1\n"
-									"\tdataSet: 0x%2\n"
+									"\tmassSpecDataSet: 0x%2\n"
 									"\torigin plot widget: 0x%3\n"
 									"\ttarget plot widget: 0x%4.\n")
 							.arg((quintptr)curRelation, QT_POINTER_SIZE * 2, 16, QChar('0'))
-							.arg((quintptr)curRelation->mp_dataSet, QT_POINTER_SIZE * 2, 16, QChar('0'))
+							.arg((quintptr)curRelation->mp_massSpecDataSet, QT_POINTER_SIZE * 2, 16, QChar('0'))
 							.arg((quintptr)curRelation->mp_originPlotWidget, QT_POINTER_SIZE * 2, 16, QChar('0'))
 							.arg((quintptr)curRelation->mp_targetPlotWidget, QT_POINTER_SIZE * 2, 16, QChar('0'));
 
