@@ -113,7 +113,8 @@ namespace msXpSmineXpert
 			void newDriftSpectrum(const MassSpecDataSet *massSpecDataSet,
 					const QString &msg, History history, QColor color);
 
-			void jsNewDriftSpectrum(const MassSpecDataSet *massSpecDataSet,
+			void jsNewDriftSpectrum(AbstractPlotWidget *caller,
+					const MassSpecDataSet *massSpecDataSet,
 					const QString &msg, History history, QColor color);
 
 			void ticIntensity(const MassSpecDataSet *massSpecDataSet,
