@@ -75,14 +75,14 @@ PeakShaperDlg::PeakShaperDlg(QWidget *parent, const QString &applicationName)
 void
 PeakShaperDlg::closeEvent(QCloseEvent *event)
 {
-  //qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
+  // qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
   writeSettings();
 }
 
 
 PeakShaperDlg::~PeakShaperDlg()
 {
-  //qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
+  // qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
 
   while(m_peakShapers.size())
     delete m_peakShapers.takeFirst();
@@ -214,7 +214,7 @@ PeakShaperDlg::craftMassSpectrumName()
 std::size_t
 PeakShaperDlg::fillInThePeakShapers()
 {
-  //qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
+  // qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
 
   // Free all the peak shapers that might have been created in a previous run.
   while(m_peakShapers.size())
@@ -242,12 +242,15 @@ PeakShaperDlg::fillInThePeakShapers()
 
       msXpSlibmass::DataPoint data_point;
 
+      // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+      //<< "Parsing current line:" << line;
+
       if(!data_point.initialize(line))
         {
           QMessageBox::warning(
             0,
             tr("mineXpert: Peak shaper (Gaussian or Lorentzian)"),
-            QString("Could not interpret data input line %s.").arg(line),
+            QString("Could not interpret data input line %1.").arg(line),
             QMessageBox::Ok);
 
           return false;
@@ -262,7 +265,7 @@ PeakShaperDlg::fillInThePeakShapers()
   message(
     QString("The number of peak centroids is: %1").arg(m_peakShapers.size()));
 
-  //qDebug() << __FILE__ << "@" << __LINE__ << "EXIT" << __FUNCTION__ << "()";
+  // qDebug() << __FILE__ << "@" << __LINE__ << "EXIT" << __FUNCTION__ << "()";
 
   return m_peakShapers.size();
 }
@@ -280,6 +283,8 @@ msXpSlibmass::DataPoint
 PeakShaperDlg::probeFirstInputDataPoint()
 {
   // We need to get the first DataPoint from the textual list of (mz,i) pairs.
+  // We iterate in the list of lines, because some might be empty. But we return
+  // the firt valid data point that is found.
 
   QString input_data_string = m_ui.inputDataPointsPlainTextEdit->toPlainText();
   QStringList input_data_string_list =
@@ -287,6 +292,9 @@ PeakShaperDlg::probeFirstInputDataPoint()
 
   QString line;
 
+  // This is an invalid data point that will be checked.
+  msXpSlibmass::DataPoint data_point;
+
   foreach(line, input_data_string_list)
     {
       // Check if line empty.
@@ -297,22 +305,15 @@ PeakShaperDlg::probeFirstInputDataPoint()
       if(msXpS::gEndOfLineRegExp.match(line).hasMatch())
         continue;
 
-      msXpSlibmass::DataPoint data_point;
-
-      if(!data_point.initialize(line))
-        qFatal(
-          "Fatal error at %s@%d -- %s(). "
-          "Could not interpret line %s."
-          "Program aborted.",
-          __FILE__,
-          __LINE__,
-          __FUNCTION__,
-          line.toLatin1().data());
+      // If the initialization fails, it returns false but also, the DataPoint
+      // is not valid, which can be tested later.
+      data_point.initialize(line);
 
       return data_point;
     }
 
-  return msXpSlibmass::DataPoint(0, 0);
+  // This is an invalid data point that will be checked.
+  return data_point;
 }
 
 
@@ -352,14 +353,15 @@ PeakShaperDlg::sortInputDataPoints()
       msXpSlibmass::DataPoint data_point;
 
       if(!data_point.initialize(line))
-        qFatal(
-          "Fatal error at %s@%d -- %s(). "
-          "Could not interpret line %s."
-          "Program aborted.",
-          __FILE__,
-          __LINE__,
-          __FUNCTION__,
-          line.toLatin1().data());
+        {
+          QMessageBox::warning(
+            0,
+            tr("mineXpert: Peak shaper (Gaussian or Lorentzian)"),
+            QString("Could not interpret data input line %1.").arg(line),
+            QMessageBox::Ok);
+
+          return QString();
+        }
 
       data_points.push_back(data_point);
     }
@@ -386,13 +388,11 @@ PeakShaperDlg::sortInputDataPoints()
 bool
 PeakShaperDlg::fetchValidateInputData()
 {
+  // qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
 
   // Remove all the text in the log text edit widget.
   m_ui.logPlainTextEdit->clear();
 
-  // Switch to the log tab so the messages are visible live.
-  m_ui.tabWidget->setCurrentIndex(static_cast<int>(TabWidgetPage::LOG));
-
   // Remove all text in the results text edit widget.
   m_ui.resultPlainTextEdit->clear();
 
@@ -401,13 +401,8 @@ PeakShaperDlg::fetchValidateInputData()
 
   if(input_mz_i_pairs.isEmpty())
     {
-      QMessageBox::warning(
-        0,
-        tr("mineXpert: Peak shaper (Gaussian or Lorentzian)"),
-        tr("Please, insert at least one (m/z i) pair in the format\n"
-           "<number><separator><number>, with <separator> being\n"
-           "any non numerical character (space or punctuation, for example)."),
-        QMessageBox::Ok);
+      qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+               << "The list of centroid peaks is empty.";
 
       return false;
     }
@@ -417,6 +412,14 @@ PeakShaperDlg::fetchValidateInputData()
 
   msXpSlibmass::DataPoint data_point = probeFirstInputDataPoint();
 
+  if(!data_point.isValid())
+    {
+      qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+               << "No valid DataPoint instance was found";
+
+      return false;
+    }
+
   // Get to know if we want gaussian or lorentzian shapes.
   if(m_ui.gaussianRadioButton->isChecked())
     {
@@ -447,36 +450,39 @@ PeakShaperDlg::fetchValidateInputData()
       return false;
     }
 
+  // At this point we'll have some things to report to the LOG tab,
+  // switch to it now.
+  m_ui.tabWidget->setCurrentIndex(static_cast<int>(TabWidgetPage::LOG));
+
   if(resolution)
     {
       // We will use the resolution
       m_config.setResolution(resolution);
 
-			double mz = data_point.key();
+      double mz = data_point.key();
 
-			double fwhm = m_config.fwhm(mz);
-      //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-               //<< "Get resolution:" << m_config.resolution(mz)
-               //<< "Compute/Get FWHM:" << fwhm;
+      double fwhm = m_config.fwhm(mz);
+      // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+      //<< "Get resolution:" << m_config.resolution(mz)
+      //<< "Compute/Get FWHM:" << fwhm;
 
       m_ui.logPlainTextEdit->appendPlainText(
         QString("Resolution is used to determine the "
                 "width of the peak shape: %1.\n"
-								"The FWHM is thus (for mz = %2): %3.\n")
+                "The FWHM is thus (for mz = %2): %3.\n")
           .arg(resolution)
-					.arg(data_point.key(), 0, 'f', 5)
-					.arg(fwhm));
+          .arg(data_point.key(), 0, 'f', 5)
+          .arg(fwhm));
     }
   else
     {
       // We will use the FWHM
       m_config.setFwhm(fwhm);
 
-			double mz = data_point.key();
-
-      //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-               //<< "Get resolution:" << m_config.resolution(mz)
-               //<< "Compute/Get FWHM:" << m_config.fwhm(mz);
+      // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+      // double mz = data_point.key();
+      //<< "Get resolution:" << m_config.resolution(mz)
+      //<< "Compute/Get FWHM:" << m_config.fwhm(mz);
 
       m_ui.logPlainTextEdit->appendPlainText(
         QString("FWHM is used to determine the "
@@ -520,6 +526,7 @@ PeakShaperDlg::fetchValidateInputData()
   m_ui.logPlainTextEdit->appendPlainText(
     m_config.asText(m_peakShapers.first()->getPeakCentroid().key()));
 
+  // qDebug() << __FILE__ << "@" << __LINE__ << "EXIT" << __FUNCTION__ << "()";
 
   return true;
 }
@@ -621,8 +628,8 @@ PeakShaperDlg::inputDataSelectionChanged()
 
   QString selectedText = cursor.selectedText();
 
-  //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-           //<< "Selected text:" << selectedText;
+  // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+  //<< "Selected text:" << selectedText;
 
   bool ok   = false;
   double mz = selectedText.toDouble(&ok);
@@ -669,15 +676,20 @@ PeakShaperDlg::execute()
       QMessageBox::warning(
         0,
         tr("mineXpert: Peak shaper (Gaussian or Lorentzian)"),
-        tr("Please, fix the input data."),
+        tr(
+          "Please, insert at least one (m/z i) pair in the following "
+          "format:\n\n"
+          "<number><separator><number>\n\n"
+          "With <separator> being any non numerical character \n"
+          "(space or non-'.' punctuation, for example).\n\n"
+          "Also, make sure that you fill-in the resolution or the FWHM value."),
         QMessageBox::Ok);
 
       return;
     }
 
   // At this point all the data are set, we can start the computation on all
-  // the
-  // various peak shapers.
+  // the various peak shapers.
 
   double minMz = std::numeric_limits<double>::max();
   double maxMz = std::numeric_limits<double>::min();
@@ -700,11 +712,6 @@ PeakShaperDlg::execute()
           fwhm                                  = config.fwhm(mz);
         }
 
-      if(mz > maxMz)
-        maxMz = mz;
-      if(mz < minMz)
-        minMz = mz;
-
       if(!peak_shaper_p->computePeakShape())
         {
           QMessageBox::warning(
@@ -716,6 +723,21 @@ PeakShaperDlg::execute()
           return;
         }
 
+      // Now that we have computed the full shape of the centroid, we'll be
+      // able to extract the smallest and greatest mz values of the whole
+      // shape.
+
+      if(peak_shaper_p->getTrace().size())
+        {
+          double smallestMz = peak_shaper_p->getTrace().first()->key();
+          double greatestMz = peak_shaper_p->getTrace().last()->key();
+
+          if(greatestMz > maxMz)
+            maxMz = greatestMz;
+          if(smallestMz < minMz)
+            minMz = smallestMz;
+        }
+
       // We want to store a list of all the mz steps for each created spectrum
       // because we'll need it to know what the size of the final mass
       // spectrum
@@ -740,15 +762,15 @@ PeakShaperDlg::execute()
     {
       binSize = fwhm / 10;
 
-      //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-               //<< "The bin size as fwhm/10 is:"
-               //<< QString("%1").arg(binSize, 0, 'f', 6);
+      qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+               << "The bin size as fwhm/10 is:"
+               << QString("%1").arg(binSize, 0, 'f', 6);
     }
   else
     {
-      //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-               //<< "The bin size set by the user is:"
-               //<< QString("%1").arg(binSize, 0, 'f', 6);
+      qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+               << "The bin size set by the user is:"
+               << QString("%1").arg(binSize, 0, 'f', 6);
     }
 
   // Now configure the combination spectrum.
@@ -806,7 +828,8 @@ PeakShaperDlg::displayMassSpectrum()
   MainWindow *main_window = static_cast<MainWindow *>(parent());
 
   main_window->createMassSpectrumFromXyText(
-    m_ui.resultPlainTextEdit->toPlainText(), m_ui.massSpectrumNameResultsLineEdit->text());
+    m_ui.resultPlainTextEdit->toPlainText(),
+    m_ui.massSpectrumNameResultsLineEdit->text());
 }
 
 } // namespace msXpSmineXpert
