@@ -1,36 +1,37 @@
-/*  BEGIN software license
+/* BEGIN software license
  *
- *  msXpertSuite - mass spectrometry software suite
- *  -----------------------------------------------
- *  Copyright(C) 2009, 2017 Filippo Rusconi
+ * msXpertSuite - mass spectrometry software suite
+ * -----------------------------------------------
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
- *  http://www.msxpertsuite.org
+ * http://www.msxpertsuite.org
  *
- *  This file is part of the msXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- *  The msXpertSuite project is the successor of the massXpert project. This
- *  project now includes various independent modules:
- *  
- *  - massXpert, model polymer chemistries and simulate mass spectrometric data;
- *  - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * The msXpertSuite project is the successor of the massXpert project. This
+ * project now includes various independent modules:
  *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation, either version 3 of the License, or
- *  (at your option) any later version.
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
  * END software license
  */
 
 
+
 /////////////////////// Qt includes
 #include <QDebug>
 
@@ -41,580 +42,6 @@
 namespace msXpSmineXpert
 {
 
-	//! Construct a HistoryItem instance
-	/*!
-
-		The instance has its date-time member datum set to current date and time and
-		is further initialized by running initializeIntegrationTypes(), that
-		initializes the \c m_intTypeDescMap member map.
-
-		\sa initializeIntegrationTypes()
-
-*/
-	HistoryItem::HistoryItem()
-	{
-		m_dateTime = QDateTime::currentDateTimeUtc();
-
-		initializeIntegrationTypes();
-	}
-
-
-	//! Construct a HistoryItem instance as a copy of \p other
-	/*!
-
-		\c this instance is initialized by running initializeIntegrationTypes(), that
-		initializes the \c m_intTypeDescMap member map.
-
-		Further initialization is performed as a deep copy of the member data in \p
-		other into \c this instance.
-
-		\param other HistoryItem instance to use for the initialization of \c this
-		instance
-
-		\sa HistoryItem()
-
-*/
-	HistoryItem::HistoryItem(const HistoryItem &other)
-	{
-
-		// Fill in all the Integration types that we know in the "static" QMap
-		// member.
-
-		initializeIntegrationTypes();
-
-		m_dateTime = other.m_dateTime;
-
-		// And now duplicate the other map.
-		QList<IntegrationRange *> list = other.m_integrationMap.values();
-
-		for(int iter = 0; iter < list.size(); ++iter)
-		{
-			IntegrationRange *intRange = list.at(iter);
-			int intType = other.m_integrationMap.key(intRange);
-
-			IntegrationRange *newIntRange = new IntegrationRange;
-			newIntRange->start = intRange->start;
-			newIntRange->end = intRange->end;
-
-			m_integrationMap.insert(intType, newIntRange);
-		}
-	}
-
-
-	//! Assignment operator.
-	/*!
-
-		The assignment of \p other to \c this instance runs a deep copy of the
-		member data in \p other into \c this instance.
-
-		Note that the m_intTypeDescMap is initialized by calling
-		initializeIntegrationTypes().
-
-		\param other HistoryItem instance to be used for the initialization of \c
-		this instance.
-
-		\return a reference to \c this HistoryItem instance.
-
-*/
-	HistoryItem &
-		HistoryItem::operator=(const HistoryItem &other)
-		{
-			// Fill in all the Integration types that we know in the "static" QMap
-			// member.
-
-			initializeIntegrationTypes();
-
-			m_dateTime = other.m_dateTime;
-
-			// And now duplicate the map.
-			QList<IntegrationRange *> list = other.m_integrationMap.values();
-
-			for(int iter = 0; iter < list.size(); ++iter)
-			{
-				IntegrationRange *intRange = list.at(iter);
-				int intType = other.m_integrationMap.key(intRange);
-
-				IntegrationRange *newIntRange = new IntegrationRange;
-				newIntRange->start = intRange->start;
-				newIntRange->end = intRange->end;
-
-				m_integrationMap.insert(intType, newIntRange);
-			}
-
-			return *this;
-		}
-
-
-	//! Destruct \c this HistoryItem instance
-	/*!
-
-		All the heap-allocated IntegrationRange and IntegrationTypeDesc instances
-		are deleted.
-
-*/
-	HistoryItem::~HistoryItem()
-	{
-		QList<IntegrationRange *> irList = m_integrationMap.values();
-
-		while(irList.size())
-			delete irList.takeFirst();
-
-		// Finally, clear the map.
-		m_integrationMap.clear();
-
-		QList<IntegrationTypeDesc *> itdList = m_intTypeDescMap.values();
-
-		while(itdList.size())
-			delete itdList.takeFirst();
-
-		// Finally, clear the map.
-		m_intTypeDescMap.clear();
-	}
-
-
-	//! Initialize the IntegrationType vs IntegrationTypeDesc map
-	/*!
-
-		The various IntegrationTypeDesc structures required to document the various
-		IntegrationType elements of the enumeration are allocated and filled-in in
-		this function. The \c m_intTypeDescMap map is then filled-in. See code for
-		the details.
-
-		Note that this function is called by the constructors and the assignement
-		operator.
-
-		\sa HistoryItem()
-
-*/
-	void
-		HistoryItem::initializeIntegrationTypes()
-		{
-
-			// The m_intTypeDescMap member is "static". Fill-in the data once and for
-			// all.
-
-			int intType = IntegrationType::NOT_SET;
-			IntegrationTypeDesc *intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "NOT_SET";
-			intTypeDesc->detailed = "Not set";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::DATA_TO_RT;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[FILE->RT]";
-			intTypeDesc->detailed = "TIC from data";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::DATA_TO_MZ;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[FILE->MZ]";
-			intTypeDesc->detailed = "Mass spectrum from data";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::DATA_TO_DT;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[FILE->DT]";
-			intTypeDesc->detailed = "Drift spectrum from data";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::RT_TO_MZ;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[RT->MZ]";
-			intTypeDesc->detailed = "Mass spectrum from Tic chromatogram";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::RT_TO_DT;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[RT->DT]";
-			intTypeDesc->detailed = "Drift time spectrum from Tic chromatogram";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::RT_TO_TIC_INT;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[RT->TICint]";
-			intTypeDesc->detailed = "TIC intensity (single value) from Tic chromatogram";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::MZ_TO_RT;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[MZ->RT]";
-			intTypeDesc->detailed = "XIC chromatogram from mass spectrum";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::MZ_TO_MZ;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[MZ->MZ]";
-			intTypeDesc->detailed = "Mass spectrum from mass spectrum";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::MZ_TO_DT;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[MZ->DT]";
-			intTypeDesc->detailed = "Drift time spectrum from mass spectrum";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::MZ_TO_TIC_INT;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[MZ->TICint]";
-			intTypeDesc->detailed = "TIC intensity (single value) from mass spectrum";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::DT_TO_RT;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[DT->RT]";
-			intTypeDesc->detailed = "XIC chromatogram from drift time spectrum";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::DT_TO_MZ;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[DT->MZ]";
-			intTypeDesc->detailed = "Mass spectrum from drift time spectrum";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::DT_TO_DT;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[DT->DT]";
-			intTypeDesc->detailed = "Drift spectrum from drift time spectrum";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::DT_TO_TIC_INT;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[DT->TICint]";
-			intTypeDesc->detailed = "TIC intensity (single value) from drift spectrum";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::RT_TO_ANY;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[RT-to-any]";
-			intTypeDesc->detailed = "Tic to any";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::MZ_TO_ANY;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[MZ-to-any]";
-			intTypeDesc->detailed = "Mass spectrum to any";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::DT_TO_ANY;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[DT-to-any]";
-			intTypeDesc->detailed = "Drift spectrum to any";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::ANY_TO_RT;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[any-to-RT]";
-			intTypeDesc->detailed = "Any to Tic";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::ANY_TO_MZ;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[any-to-MZ]";
-			intTypeDesc->detailed = "Any to Mass spectrum";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::ANY_TO_DT;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[any-to-DT]";
-			intTypeDesc->detailed = "Any to Drift spectrum";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-
-			intType = IntegrationType::ANY_TO_TIC_INT;
-			intTypeDesc = new IntegrationTypeDesc;
-			intTypeDesc->brief = "[any-to-DT]";
-			intTypeDesc->detailed = "Any to TIC intensity (single value)";
-			m_intTypeDescMap.insert(intType, intTypeDesc);
-		}
-
-
-	//! Equality operator.
-	/*!
-
-		Two HistoryItem instances are equal if all their members are identical. Note
-		that the order of the items in the \c m_integrationMap is not relevant and
-		that the \c m_intTypeDescMap is not checked since it is considered
-		immutable.
-
-		Note that the IntegrationType instances pointed to by items in the \c
-		m_integrationMap map are tested for \c start and \c end values, not by
-		pointer value.
-
-		\param other reference to a HistoryItem instance to compare to \c this
-		instance.
-
-		\return true if both HistoryItem instances are identical.
-
-		\sa contains()
-
-*/
-	bool
-		HistoryItem::operator==(const HistoryItem &other) const
-		{
-			if(this == &other)
-				return true;
-
-			if(m_dateTime != other.m_dateTime)
-				return false;
-
-			// Now we need to compare all the pairs in the map.
-
-			if(m_integrationMap.size() != other.m_integrationMap.size())
-				return false;
-
-			QList<int> intTypeList = m_integrationMap.keys();
-
-			for(int iter = 0; iter < intTypeList.size(); ++iter)
-			{
-				int intType = intTypeList.at(iter);
-
-				IntegrationRange *intRange = m_integrationMap.value(intType);
-
-				if(other.contains(intType, *intRange))
-					continue;
-				else
-					return false;
-			}
-
-			return true;
-		}
-
-
-	//! Verifies if the \c m_integrationMap contains an item
-	/*!
-
-		The \c m_integrationMap map is checked for having a value mapped to the \p
-		intType parameter that has the same IntegrationRange values start and end as
-		the \p &intRange.
-
-		\param intType IntegrationType key to search in the \c m_integrationMap.
-
-		\param intRange reference to an IntegrationRange instance to be used for the
-		comparison.
-
-		\return True if an IntegrationRange instance is found as value in \c
-		m_integrationMap that has the same \c start and \c end member values as \p
-		&intRange.
-
-		\sa operator==()
-
-*/
-	bool
-		HistoryItem::contains(int intType, const IntegrationRange &intRange) const
-		{
-			IntegrationRange *localRange = m_integrationMap.value(intType, Q_NULLPTR);
-
-			if(localRange == Q_NULLPTR)
-				return false;
-
-			if(localRange->start == intRange.start && localRange->end == intRange.end)
-				return true;
-
-			return false;
-		}
-
-
-	//! Set the date and time to the current date and time
-	/*!
-
-		The date and time format is UTC (universal time coordinated).
-
-*/
-	void
-		HistoryItem::setDateTime()
-		{
-			m_dateTime = QDateTime::currentDateTimeUtc();
-		}
-
-
-	//! Get the date and time of \c this HistoryItem instance.
-	/*!
-
-		\return The date and time in QDateTime format.
-
-		\sa setDateTime()
-
-*/
-	QDateTime
-		HistoryItem::dateTime() const
-		{
-			return m_dateTime;
-		}
-
-
-	//! Checks if \c this HistoryItem instance has an IntegrationType
-	/*!
-
-		The \c m_integrationMap map is queried for a key having the same value as \p integrationType.
-
-		\param integrationType IntegrationType value to search as a key of the \c
-		m_integrationMap map.
-
-		\return true if \c m_integrationMap has at an integration type identical to
-		\p integrationType; false otherwise.
-
-		\sa
-
-*/
-	bool
-		HistoryItem::hasIntegrationType(int integrationType)
-		{
-			QList<int> list = m_integrationMap.keys();
-
-			if(list.contains(integrationType))
-				return true;
-
-			return false;
-		}
-
-
-	//! Creates a new IntegrationRange instance and inserts it in the member map
-	/*!
-
-		\param intType IntegrationType value used for the map insertion
-
-		\param start start of range used for the creation of the IntegrationRange instance
-
-		\param end end of range used for the creation of the IntegrationRange instance
-
-
-*/
-	void
-		HistoryItem::newIntegrationRange(int intType, double start,
-				double end)
-		{
-			IntegrationRange *intRange = new IntegrationRange;
-			intRange->start = start;
-			intRange->end = end;
-
-			m_integrationMap.insert(intType, intRange);
-		}
-
-
-	IntegrationRange *
-		HistoryItem::integrationRange(int intType) const
-		{
-			IntegrationRange *intRange = m_integrationMap.value(intType, Q_NULLPTR);
-			return intRange;
-		}
-
-
-	int  
-		HistoryItem::integrationType(IntegrationRange *integrationRange)
-		{
-			if(integrationRange == Q_NULLPTR)
-				qFatal("Fatal error at %s@%d -- %s. "
-						"Q_NULLPTR."
-						"Program aborted.",
-						__FILE__, __LINE__, __FUNCTION__);
-
-			return m_integrationMap.key(integrationRange);
-		}
-
-
-	//! Get a list of IntegrationType values matching the integration ranges.
-	/*!
-
-		A given HistoryItem instance might have more than one integration range, and
-		for each one of these integration ranges, it might have different
-		IntegrationType values. This function returns the list of keys of the \c
-		m_integrationMap QMap<IntegrationType, IntegrationRange *> map.
-
-		One typical situation is when performing an integration from the color map
-		widget, that is, integrating using two ranges: the mz range and the dt range
-		(ion mobility mass spectrometry only).
-
-*/
-	QList<int> 
-		HistoryItem::integrationTypes() const
-		{
-			return m_integrationMap.keys();
-		}
-
-
-	QList<IntegrationRange *> 
-		HistoryItem::integrationRanges() const
-		{
-			return m_integrationMap.values();
-		}
-
-
-	bool
-		HistoryItem::isValid() const
-		{
-			if(!m_dateTime.isValid())
-				return false;
-
-			if(m_integrationMap.isEmpty())
-				return false;
-
-			return true;
-		}
-
-
-	QString
-		HistoryItem::asText(bool brief) const
-		{
-			QString text;
-
-			// For each integration range in the map, craft a text element.
-
-			QList<IntegrationRange *> list = m_integrationMap.values();
-
-			//qDebug() << __FILE__ << __LINE__ << "There are " << list.size()
-			//<< " integration ranges in the map";
-
-			for(int iter = 0; iter < list.size(); ++iter)
-			{
-				IntegrationRange *intRange = list.at(iter);
-				int intType = m_integrationMap.key(intRange);
-
-				//qDebug() << __FILE__ << __LINE__
-					//<< "Currently iterated intType:" << intType;
-
-				IntegrationTypeDesc *intTypeDesc = m_intTypeDescMap.value(intType);
-
-				if(intTypeDesc == nullptr)
-					qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
-
-				QString label;
-
-				if(brief)
-					label = intTypeDesc->brief + " ";
-				else
-					label = intTypeDesc->detailed + ":\n";
-
-				if(brief)
-				{
-					text += label +
-						QString("range: [%1-%2]")
-						.arg(intRange->start, 0, 'f', 3)
-						.arg(intRange->end, 0, 'f', 3);
-
-					if(iter > 0 && iter < list.size() - 1)
-						text += " | ";
-					if(iter == list.size() - 1)
-						text += "\n";
-				}
-				else
-					text += label +
-						QString("\tRange: [%1-%2]\n")
-						.arg(intRange->start, 0, 'f', 3)
-						.arg(intRange->end, 0, 'f', 3);
-			}
-
-			// Finally, only print the date time if we are verbose.
-			if(!brief)
-			{
-				text += "\t" + m_dateTime.toString(Qt::ISODate);
-				text += "\n";
-			}
-
-
-			// qDebug() << __FILE__ << __LINE__ << "text: " << text;
-
-			return text;
-		}
-
 
 	//! Construct an emtpy History instance.
 	/*!
@@ -624,7 +51,6 @@ namespace msXpSmineXpert
 	{
 	}
 
-
 	//! Construct a History instance as the copy of another.
 	/*!
 
@@ -640,6 +66,8 @@ namespace msXpSmineXpert
 	{
 		for(int iter = 0; iter < other.m_historyItemList.size(); ++iter)
 			m_historyItemList.append(new HistoryItem(*(other.m_historyItemList.at(iter))));
+
+		m_mzIntegrationParams = other.m_mzIntegrationParams;
 	}
 
 
@@ -661,6 +89,10 @@ namespace msXpSmineXpert
 			if(&other == this)
 				return *this;
 
+			m_mzIntegrationParams.reset();
+			m_mzIntegrationParams = other.m_mzIntegrationParams;
+
+			freeList();
 			for(int iter = 0; iter < other.m_historyItemList.size(); ++iter)
 				m_historyItemList.append(new HistoryItem(*(other.m_historyItemList.at(iter))));
 
@@ -682,6 +114,28 @@ namespace msXpSmineXpert
 	}
 
 
+	//! Tell if the member list of HistoryItem instances is empty.
+	bool
+		History::isEmpty()
+		{
+			return m_historyItemList.isEmpty();
+		}
+
+
+	void
+		History::setMzIntegrationParams(MzIntegrationParams params)
+		{
+			m_mzIntegrationParams = params;
+		}
+
+
+	MzIntegrationParams
+		History::mzIntegrationParams() const
+		{
+			return m_mzIntegrationParams;
+		}
+
+
 	//! Deletes all the items in the History item list.
 	/*!
 
@@ -756,14 +210,14 @@ namespace msXpSmineXpert
 
 				if(item->hasIntegrationType(intType))
 				{
-					if(intRange != nullptr)
+					if(intRange != Q_NULLPTR)
 						*intRange = item->integrationRange(intType);
 
 					return item;
 				}
 			}
 
-			return nullptr;
+			return Q_NULLPTR;
 		}
 
 
@@ -798,14 +252,14 @@ namespace msXpSmineXpert
 
 				if(item->hasIntegrationType(intType))
 				{
-					if(intRange != nullptr)
+					if(intRange != Q_NULLPTR)
 						*intRange = item->integrationRange(intType);
 
 					return item;
 				}
 			}
 
-			return nullptr;
+			return Q_NULLPTR;
 		}
 
 
@@ -834,13 +288,13 @@ namespace msXpSmineXpert
 			QDateTime newestDateTime = m_historyItemList.first()->m_dateTime;
 			int newestDateTimeIndex = 0;
 
-			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ 
-				//<< "First history item:" << m_historyItemList.first()->asText();
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__
+			//<< "First history item:" << m_historyItemList.first()->asText();
 
 			for(int iter = 1; iter < m_historyItemList.size(); ++iter)
 			{
-				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ 
-					//<< "iterating in second history item.";
+				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__
+				//<< "iterating in second history item.";
 
 				HistoryItem *historyItem = m_historyItemList.at(iter);
 
@@ -848,9 +302,9 @@ namespace msXpSmineXpert
 
 				if(iterDateTime > newestDateTime)
 				{
-					//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ 
-						//<< "This history item is more recent:"
-						//<< historyItem->asText();
+					//qDebug() << __FILE__ << __LINE__ << __FUNCTION__
+					//<< "This history item is more recent:"
+					//<< historyItem->asText();
 
 					newestDateTime = iterDateTime;
 					newestDateTimeIndex = iter;
@@ -899,6 +353,9 @@ namespace msXpSmineXpert
 					m_historyItemList.append(newItem);
 				}
 			}
+
+			// Finally, the m/z integration parameters
+			m_mzIntegrationParams = history.m_mzIntegrationParams;
 		}
 
 
@@ -918,7 +375,7 @@ namespace msXpSmineXpert
 	int
 		History::appendHistoryItem(HistoryItem *item)
 		{
-			if(item == nullptr)
+			if(item == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			m_historyItemList.append(item);
@@ -978,7 +435,7 @@ namespace msXpSmineXpert
 	bool
 		History::innermostRtRange(double *start, double *end) const
 		{
-			if(start == nullptr || end == nullptr)
+			if(start == Q_NULLPTR || end == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			double tempStart = -1;
@@ -987,33 +444,21 @@ namespace msXpSmineXpert
 			bool itemFound = false;
 			bool firstItem = true;
 
-			QList<IntegrationType> intTypeList{IntegrationType::RT_TO_MZ,
-				IntegrationType::RT_TO_DT,
-				IntegrationType::RT_TO_TIC_INT,
-				IntegrationType::ANY_TO_RT};
-
-			// Iterate in the list of HistoryItem instances and for each check if there
-			// is a (IntegrationType, IntegrationRange) pair in the QMap that matches
-			// one of the RT_XXXX integration types. Thas is we search for integrations
-			// that are defined *starting* from an RT range. If so store the start and
-			// end values in temporary variables and make sure we finally get the
-			// greatest start value and the smallest end value (we are seeking innermost
-			// range values.
-
 			for(int iter = 0; iter < m_historyItemList.size(); ++iter)
 			{
 				HistoryItem *item = m_historyItemList.at(iter);
 
-				// Each history item my have one of the IntegrationType values related
-				// to RT integration. Let's test them all in sequence.
+				// A history item might contain more than one integration range.
+				// Ask a list of these.
 
-				for(int iter = 0; iter < intTypeList.size(); ++iter)
+				QList<IntegrationRange *> intRangeList = item->integrationRanges();
+
+				for(int iter = 0; iter < intRangeList.size(); ++iter)
 				{
-					IntegrationType intType = intTypeList.at(iter);
+					IntegrationRange *intRange = intRangeList.at(iter);
+					int integType = item->integrationType(intRange);
 
-					IntegrationRange *intRange = item->integrationRange(intType);
-
-					if(intRange != nullptr)
+					if(integType & IntegrationType::RT_TO_ANY)
 					{
 						if(firstItem)
 						{
@@ -1024,15 +469,32 @@ namespace msXpSmineXpert
 						}
 						else
 						{
-							// We seek the *innermost* range, so be aware of the
-							// relational < >
-							// operators.
+							// We seek the *innermost* range, so be aware of the relational < > operators that may look used at reverse but are not.
+
 							if(intRange->start > tempStart)
 								tempStart = intRange->start;
+
 							if(intRange->end < tempEnd)
 								tempEnd = intRange->end;
 						}
 
+						//QString matchingBin= QString("%1").arg(integType, 0, 2);
+						//QString matchedBin= QString("%1").arg(IntegrationType::DT_TO_ANY, 0, 2);
+
+						//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+							//<< "new integration range"
+							//<< integType
+							//<< "(" << HistoryItem::m_integrationTypeDescriptionMap.value(integType)->brief << ")"
+							//"<< matches" << IntegrationType::DT_TO_ANY << "bin:" << matchingBin
+							//<< "(" <<  HistoryItem::m_integrationTypeDescriptionMap.value(IntegrationType::RT_TO_ANY)->brief << ")"
+							//<< "bin:" << matchedBin
+							//<< "with tempStart:" << tempStart << "tempEnd:" << tempEnd;
+
+						//int result = item->integrationType(intRange) & IntegrationType::RT_TO_ANY;
+						//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+							//"result:" << result << "bin:" << QString("%1").arg(result, 0, 2);
+
+
 						// Let the caller know that we found at least one item and thus
 						// that the start and end params now have the encountered
 						// values.
@@ -1040,7 +502,7 @@ namespace msXpSmineXpert
 						itemFound = true;
 					}
 					else
-						// The returned intRange is nullptr.
+						// The returned intRange is Q_NULLPTR.
 						continue;
 				}
 			}
@@ -1080,7 +542,7 @@ namespace msXpSmineXpert
 	bool
 		History::innermostMzRange(double *start, double *end) const
 		{
-			if(start == nullptr || end == nullptr)
+			if(start == Q_NULLPTR || end == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			double tempStart = -1;
@@ -1101,8 +563,9 @@ namespace msXpSmineXpert
 				for(int iter = 0; iter < intRangeList.size(); ++iter)
 				{
 					IntegrationRange *intRange = intRangeList.at(iter);
+					int integType = item->integrationType(intRange);
 
-					if(item->integrationType(intRange) & MZ_TO_ANY)
+					if(integType & IntegrationType::MZ_TO_ANY)
 					{
 						if(firstItem)
 						{
@@ -1114,8 +577,8 @@ namespace msXpSmineXpert
 						else
 						{
 
-							// We seek the *innermost* range, so be aware of the relational <
-							// > operators that may look used at reverse but are not.
+							// We seek the *innermost* range, so be aware of the relational < >
+							// operators that may look used at reverse but are not.
 
 							if(intRange->start > tempStart)
 								tempStart = intRange->start;
@@ -1124,6 +587,27 @@ namespace msXpSmineXpert
 								tempEnd = intRange->end;
 						}
 
+						//QString matchingBin= QString("%1").arg(integType, 0, 2);
+						//QString matchedBin= QString("%1").arg(IntegrationType::DT_TO_ANY, 0, 2);
+
+						//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+							//<< "new integration range"
+							//<< integType
+							//<< "(" << HistoryItem::m_integrationTypeDescriptionMap.value(integType)->brief << ")"
+							//"<< matches" << IntegrationType::DT_TO_ANY << "bin:" << matchingBin
+							//<< "(" <<  HistoryItem::m_integrationTypeDescriptionMap.value(IntegrationType::MZ_TO_ANY)->brief << ")"
+							//<< "bin:" << matchedBin
+							//<< "with tempStart:" << tempStart << "tempEnd:" << tempEnd;
+
+						//int result = item->integrationType(intRange) & IntegrationType::MZ_TO_ANY;
+						//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+							//"result:" << result << "bin:" << QString("%1").arg(result, 0, 2);
+
+
+						// Let the caller know that we found at least one item and thus
+						// that the start and end params now have the encountered
+						// values.
+
 						itemFound = true;
 					}
 				}
@@ -1139,6 +623,9 @@ namespace msXpSmineXpert
 			*start = tempStart;
 			*end = tempEnd;
 
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "start: " << *start << "end:" << *end << "item was found:" << itemFound;
+
 			return itemFound;
 		}
 
@@ -1170,7 +657,7 @@ namespace msXpSmineXpert
 	bool
 		History::innermostDtRange(double *start, double *end) const
 		{
-			if(start == nullptr || end == nullptr)
+			if(start == Q_NULLPTR || end == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			double tempStart = -1;
@@ -1193,8 +680,9 @@ namespace msXpSmineXpert
 				for(int iter = 0; iter < intRangeList.size(); ++iter)
 				{
 					IntegrationRange *intRange = intRangeList.at(iter);
+					int integType = item->integrationType(intRange);
 
-					if(item->integrationType(intRange) & DT_TO_ANY)
+					if(integType & IntegrationType::DT_TO_ANY)
 					{
 						if(firstItem)
 						{
@@ -1216,6 +704,27 @@ namespace msXpSmineXpert
 								tempEnd = intRange->end;
 						}
 
+						//QString matchingBin= QString("%1").arg(integType, 0, 2);
+						//QString matchedBin= QString("%1").arg(IntegrationType::DT_TO_ANY, 0, 2);
+
+						//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+							//<< "new integration range"
+							//<< integType
+							//<< "(" << HistoryItem::m_integrationTypeDescriptionMap.value(integType)->brief << ")"
+							//"<< matches" << IntegrationType::DT_TO_ANY << "bin:" << matchingBin
+							//<< "(" <<  HistoryItem::m_integrationTypeDescriptionMap.value(IntegrationType::DT_TO_ANY)->brief << ")"
+							//<< "bin:" << matchedBin
+							//<< "with tempStart:" << tempStart << "tempEnd:" << tempEnd;
+
+						//int result = item->integrationType(intRange) & IntegrationType::DT_TO_ANY;
+						//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+							//"result:" << result << "bin:" << QString("%1").arg(result, 0, 2);
+
+
+						// Let the caller know that we found at least one item and thus
+						// that the start and end params now have the encountered
+						// values.
+
 						itemFound = true;
 					}
 				}
@@ -1362,6 +871,8 @@ namespace msXpSmineXpert
 		{
 			QString text = header;
 
+			text += m_mzIntegrationParams.asText();
+
 			for(int iter = 0; iter < m_historyItemList.size(); ++iter)
 				text += m_historyItemList.at(iter)->asText(brief);
 
