@@ -68,7 +68,7 @@ namespace msXpSmineXpert
 	void
 		HistoryItem::prepareIntegrationTypeDescriptionMap()
 		{
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 
 			int intType = IntegrationType::NOT_SET;
 			IntegrationTypeDesc *intTypeDesc = new IntegrationTypeDesc;
