@@ -942,7 +942,6 @@ namespace msXpSmineXpert
 			if(mp_massSpecDataSet->isStreamed())
 				return streamIntegrateToMz();
 
-			m_keyVector.clear();
 			m_valVector.clear();
 
 			// Sanity check
@@ -1248,7 +1247,7 @@ namespace msXpSmineXpert
 
 				savGolFilter.initializeData(m_keyVector, m_valVector);
 
-				savGolFilter.sgfilter();
+				savGolFilter.filter();
 
 				QVector<double> filtered;
 				savGolFilter.filteredData(filtered);
@@ -1721,7 +1720,7 @@ namespace msXpSmineXpert
 
 			int rtListSize = rtList.size();
 
-			QString msg("Integrating to TIC intensity");
+			QString msg = QString("Integrating to TIC intensity");
 
 			m_progressFeedbackStartValue = 0;
 			m_progressFeedbackEndValue = rtListSize;
@@ -1800,7 +1799,7 @@ namespace msXpSmineXpert
 					if(omp_get_thread_num() == 0)
 						emit updateFeedbackSignal(msg,
 								iterationCount, true /* setVisible */,
-								LogType::LOG_TO_BOTH, m_progressFeedbackStartValue, m_progressFeedbackEndValue);
+								LogType::LOG_TO_STATUS_BAR, m_progressFeedbackStartValue, m_progressFeedbackEndValue);
 				}
 			}
 			// End of
