@@ -39,6 +39,7 @@
 #include <QRegularExpression>
 #include <QDebug>
 #include <QVector>
+#include <QCoreApplication>
 
 #include <qmath.h>
 
@@ -443,6 +444,8 @@ namespace msXpSmineXpert
 
 			while(!file.atEnd())
 			{
+				QCoreApplication::processEvents();
+
 				if(m_isOperationCancelled)
 					break;
 
@@ -605,8 +608,8 @@ namespace msXpSmineXpert
 
 				QString msg = QString("Parsed spectrum number %1\n").arg(spectraRead);
 
-				emit dataLoadMessageSignal(msg, LOG_TO_BOTH);
-				emit dataLoadProgressSignal(spectraRead);
+				emit updateFeedbackSignal(msg, spectraRead, true /* setVisible */,
+						LogType::LOG_TO_BOTH);
 			}
 			// End of
 			// while(!file.atEnd())
@@ -772,7 +775,7 @@ namespace msXpSmineXpert
 
 			QString msgSkeleton = "Computing streamed m/z integration";
 
-			emit setupFeedbackSignal(msgSkeleton, 0, 0, -1, LogType::LOG_TO_BOTH);
+			emit updateFeedbackSignal(msgSkeleton, 0, true /* setVisible */, LogType::LOG_TO_BOTH);
 
 			while(!file.atEnd())
 			{
@@ -912,7 +915,7 @@ namespace msXpSmineXpert
 					QString msg =
 						QString(" -- spectrum number %1\n").arg(spectraRead);
 
-					emit updateFeedbackSignal(msgSkeleton + msg, -1, LogType::LOG_TO_STATUS_BAR);
+					emit updateFeedbackSignal(msgSkeleton + msg, -1, true /* setVisible */, LogType::LOG_TO_STATUS_BAR);
 
 					// qDebug() << __FILE__ << __LINE__ << msg;
 				}
