@@ -46,8 +46,6 @@
 #include <pwiz/data/msdata/MSDataFile.hpp>
 #include <pwiz/data/msdata/DefaultReaderList.hpp>
 
-using namespace pwiz::msdata;
-
 
 namespace msXpSmineXpert
 {
@@ -272,7 +270,7 @@ MassSpecDataFileLoaderPwiz::containsMobilityData()
   // located.
 
   std::string head;
-  MSData result;
+	pwiz::msdata::MSData result;
 
   if(!canLoadData(m_fileName, this))
     return false;
@@ -292,7 +290,7 @@ MassSpecDataFileLoaderPwiz::containsMobilityData()
                       result,
                       /* int runIndex */ 0);
 
-  SpectrumListPtr spectrumListPtr = result.run.spectrumListPtr;
+	pwiz::msdata::SpectrumListPtr spectrumListPtr = result.run.spectrumListPtr;
 
   if(!spectrumListPtr->size())
     qFatal(
@@ -302,10 +300,10 @@ MassSpecDataFileLoaderPwiz::containsMobilityData()
       __FILE__,
       __LINE__);
 
-  SpectrumPtr spectrumPtr =
+	pwiz::msdata::SpectrumPtr spectrumPtr =
     spectrumListPtr->spectrum(/*index*/ 0, false /*getBinaryData*/);
 
-  ScanList scanList = spectrumPtr->scanList;
+  pwiz::msdata::ScanList scanList = spectrumPtr->scanList;
 
   // Then look at the param of each single scan of the scanList
 
@@ -322,13 +320,13 @@ MassSpecDataFileLoaderPwiz::containsMobilityData()
 
   for(uint lter = 0; lter < scanList.scans.size(); ++lter)
     {
-      Scan scan = scanList.scans.at(lter);
+      pwiz::msdata::Scan scan = scanList.scans.at(lter);
 
       for(uint mter = 0; mter < scan.cvParams.size(); ++mter)
         {
-          CVParam cvParam = scan.cvParams.at(mter);
+          pwiz::msdata::CVParam cvParam = scan.cvParams.at(mter);
 
-          if(cvParam.cvid == MS_ion_mobility_drift_time)
+          if(cvParam.cvid == pwiz::msdata::MS_ion_mobility_drift_time)
             {
               // In mineXpert drift times are always in milliseconds.
               double driftTime = cvParam.timeInSeconds() * 1000;
@@ -429,7 +427,7 @@ MassSpecDataFileLoaderPwiz::seedDataLoading()
   mp_spectrumListPtr = m_msDataResult.run.spectrumListPtr;
   // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
   //<< "spectrum list ptr:" << mp_spectrumListPtr.get();
-  SpectrumPtr spectrumPtr =
+  pwiz::msdata::SpectrumPtr spectrumPtr =
     mp_spectrumListPtr->spectrum(/*index*/ 0, true /*getBinaryData*/);
   // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
   //<< "spectrum ptr:" << spectrumPtr.get();
@@ -501,7 +499,7 @@ MassSpecDataFileLoaderPwiz::nextSpectrum(
   //<< "spectrum list ptr:" << mp_spectrumListPtr.get()
   //<< "size of spectrum list:" << mp_spectrumListPtr->size();
 
-  SpectrumPtr spectrumPtr = mp_spectrumListPtr->spectrum(
+  pwiz::msdata::SpectrumPtr spectrumPtr = mp_spectrumListPtr->spectrum(
     /*index*/ m_spectrumIndex, true /*getBinaryData*/);
 
   // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
@@ -512,14 +510,14 @@ MassSpecDataFileLoaderPwiz::nextSpectrum(
   // We need some cvParam data from the spectrum itself.
   for(uint iter = 0; iter < spectrumPtr->cvParams.size(); ++iter)
     {
-      CVParam cvParam = spectrumPtr->cvParams.at(iter);
+      pwiz::msdata::CVParam cvParam = spectrumPtr->cvParams.at(iter);
 
-      if(cvParam.cvid == MS_spectrum_title)
+      if(cvParam.cvid == pwiz::msdata::MS_spectrum_title)
         {
           m_spectrumTitle =
             QString::fromStdString(cvParam.valueAs<std::string>());
         }
-      else if(cvParam.cvid == MS_ms_level)
+      else if(cvParam.cvid == pwiz::msdata::MS_ms_level)
         {
           m_msLevel = cvParam.valueAs<int>();
 
@@ -530,7 +528,7 @@ MassSpecDataFileLoaderPwiz::nextSpectrum(
 
   m_specPeakCount = spectrumPtr->getMZArray()->data.size();
 
-  ScanList scanList = spectrumPtr->scanList;
+  pwiz::msdata::ScanList scanList = spectrumPtr->scanList;
 
   // Then look at the param of each single scan of the scanList
 
@@ -548,13 +546,13 @@ MassSpecDataFileLoaderPwiz::nextSpectrum(
 
   for(uint lter = 0; lter < scanList.scans.size(); ++lter)
     {
-      Scan scan = scanList.scans.at(lter);
+      pwiz::msdata::Scan scan = scanList.scans.at(lter);
 
       for(uint mter = 0; mter < scan.cvParams.size(); ++mter)
         {
-          CVParam cvParam = scan.cvParams.at(mter);
+          pwiz::msdata::CVParam cvParam = scan.cvParams.at(mter);
 
-          if(cvParam.cvid == MS_scan_start_time)
+          if(cvParam.cvid == pwiz::msdata::MS_scan_start_time)
             {
               // Retention times are always in minutes.
               m_scanStartTime = cvParam.timeInSeconds() / 60;
@@ -580,7 +578,7 @@ MassSpecDataFileLoaderPwiz::nextSpectrum(
                   //break;
                 //}
             }
-          else if(cvParam.cvid == MS_ion_mobility_drift_time)
+          else if(cvParam.cvid == pwiz::msdata::MS_ion_mobility_drift_time)
             {
               QString value = QString::fromStdString(cvParam.value);
 
@@ -620,13 +618,13 @@ MassSpecDataFileLoaderPwiz::nextSpectrum(
               iter < scan.scanWindows.at(firstOne).cvParams.size();
               ++iter)
             {
-              CVParam cvParam = scan.scanWindows.at(firstOne).cvParams.at(iter);
+              pwiz::msdata::CVParam cvParam = scan.scanWindows.at(firstOne).cvParams.at(iter);
 
-              if(cvParam.cvid == MS_scan_window_lower_limit)
+              if(cvParam.cvid == pwiz::msdata::MS_scan_window_lower_limit)
                 {
                   m_scanWindowLowerLimit = cvParam.valueAs<double>();
                 }
-              else if(cvParam.cvid == MS_scan_window_upper_limit)
+              else if(cvParam.cvid == pwiz::msdata::MS_scan_window_upper_limit)
                 {
                   m_scanWindowUpperLimit = cvParam.valueAs<double>();
                 }
@@ -675,8 +673,8 @@ msXpSlibmass::MassSpectrum *
 MassSpecDataFileLoaderPwiz::createNewSpectrum(
   pwiz::msdata::SpectrumPtr spectrumPtr)
 {
-  BinaryDataArrayPtr mzArrayPtr = spectrumPtr->getMZArray();
-  BinaryDataArrayPtr iArrayPtr  = spectrumPtr->getIntensityArray();
+  pwiz::msdata::BinaryDataArrayPtr mzArrayPtr = spectrumPtr->getMZArray();
+  pwiz::msdata::BinaryDataArrayPtr iArrayPtr  = spectrumPtr->getIntensityArray();
 
   // Sanity check:
   if(mzArrayPtr->data.size() != iArrayPtr->data.size())
@@ -1482,27 +1480,27 @@ MassSpecDataFileLoaderPwiz::canLoadData(QString fileName,
 
   // We use the pwiz facilities to check if it can handle the file at hand.
   std::string head;
-  MSData result;
+  pwiz::msdata::MSData result;
 
   // The default reader list handles mzML, mzXML, and other common formats.
-  ReaderPtr readerListPtr(new DefaultReaderList);
-  CVID cvId = identifyFileFormat(readerListPtr, fileName.toStdString());
+  pwiz::msdata::ReaderPtr readerListPtr(new pwiz::msdata::DefaultReaderList);
+  pwiz::msdata::CVID cvId = identifyFileFormat(readerListPtr, fileName.toStdString());
 
   // CVTermInfo cvInfo = cvTermInfo(cvId);
   // qDebug() << __FILE__ << __LINE__
   //<< "cvId:" << QString().fromStdString(cvInfo.shortName());
 
-  if(cvId == MS_mzML_format)
+  if(cvId == pwiz::msdata::MS_mzML_format)
     {
       if(pwiz)
-        pwiz->mp_pwizReader = static_cast<ReaderPtr>(new Reader_mzML);
+        pwiz->mp_pwizReader = static_cast<pwiz::msdata::ReaderPtr>(new pwiz::msdata::Reader_mzML);
 
       return MassSpecDataFileFormat::MASS_SPEC_DATA_FILE_FORMAT_MZML;
     }
-  else if(cvId == MS_ISB_mzXML_format)
+  else if(cvId == pwiz::msdata::MS_ISB_mzXML_format)
     {
       if(pwiz)
-        pwiz->mp_pwizReader = static_cast<ReaderPtr>(new Reader_mzXML);
+        pwiz->mp_pwizReader = static_cast<pwiz::msdata::ReaderPtr>(new pwiz::msdata::Reader_mzXML);
 
       return MassSpecDataFileFormat::MASS_SPEC_DATA_FILE_FORMAT_MZXML;
     }
@@ -1523,7 +1521,7 @@ int
 MassSpecDataFileLoaderPwiz::readSpectrumCount()
 {
   std::string head;
-  MSData result;
+  pwiz::msdata::MSData result;
 
   if(!canLoadData(m_fileName, this))
     return -1;
@@ -1543,7 +1541,7 @@ MassSpecDataFileLoaderPwiz::readSpectrumCount()
                       result,
                       /* int runIndex */ 0);
 
-  SpectrumListPtr spectrumListPtr = result.run.spectrumListPtr;
+  pwiz::msdata::SpectrumListPtr spectrumListPtr = result.run.spectrumListPtr;
   m_spectrumCount                 = spectrumListPtr->size();
 
   return m_spectrumCount;
@@ -1599,7 +1597,7 @@ MassSpecDataFileLoaderPwiz::loadDataToMassSpecDataSet(
   // The counter of spectra that we iterated over.
   int count = 0;
 
-  SpectrumPtr spectrumPtr = Q_NULLPTR;
+  pwiz::msdata::SpectrumPtr spectrumPtr = Q_NULLPTR;
 
   while(nextSpectrum(&spectrumPtr) != -1)
     {
@@ -1743,7 +1741,7 @@ MassSpecDataFileLoaderPwiz::loadDataToXyFiles(const QString &xyFileName,
   // Count of the spectra that were iterated over
   int count = 0;
 
-  SpectrumPtr spectrumPtr;
+  pwiz::msdata::SpectrumPtr spectrumPtr;
 
   while(m_spectrumIndex >= specIndexStart - 1 &&
         m_spectrumIndex < specIndexEnd - 1 && nextSpectrum(&spectrumPtr) != -1)
@@ -1907,7 +1905,7 @@ MassSpecDataFileLoaderPwiz::loadDataToDatabase(const QString &dbFileName)
   // The counter of spectra that we iterated over.
   int count = 0;
 
-  SpectrumPtr spectrumPtr = Q_NULLPTR;
+  pwiz::msdata::SpectrumPtr spectrumPtr = Q_NULLPTR;
 
   while(nextSpectrum(&spectrumPtr) != -1)
     {
@@ -1928,8 +1926,8 @@ MassSpecDataFileLoaderPwiz::loadDataToDatabase(const QString &dbFileName)
       if(spectrumPtr != Q_NULLPTR)
         {
           // For this task we need the Pwiz data
-          BinaryDataArrayPtr mzArrayPtr = spectrumPtr->getMZArray();
-          BinaryDataArrayPtr iArrayPtr  = spectrumPtr->getIntensityArray();
+          pwiz::msdata::BinaryDataArrayPtr mzArrayPtr = spectrumPtr->getMZArray();
+          pwiz::msdata::BinaryDataArrayPtr iArrayPtr  = spectrumPtr->getIntensityArray();
 
           // Sanity check:
           if(mzArrayPtr->data.size() != iArrayPtr->data.size())
@@ -2009,7 +2007,7 @@ MassSpecDataFileLoaderPwiz::loadDataToDatabase(const QString &dbFileName)
 
           m_dataCompression = msXpS::DataCompression::DATA_COMPRESSION_ZLIB;
 
-          BinaryDataEncoder encoder(config);
+          pwiz::msdata::BinaryDataEncoder encoder(config);
 
           std::string result;
           size_t binaryByteCount;
@@ -2194,7 +2192,7 @@ MassSpecDataFileLoaderPwiz::streamedIntegration(const History &history,
   // qDebug() << __FILE__ << __LINE__
   //<< "We are parsing to the vectors.";
 
-  SpectrumPtr spectrumPtr = Q_NULLPTR;
+  pwiz::msdata::SpectrumPtr spectrumPtr = Q_NULLPTR;
 
   // Counter of the effectively loaded spectra
   m_storedSpectraCount = 0;
@@ -2476,7 +2474,7 @@ MassSpecDataFileLoaderPwiz::streamedTicIntensity(const History &history,
   m_massSpectrum.deleteDataPoints();
   m_massSpectrum.clear();
 
-  SpectrumPtr spectrumPtr = Q_NULLPTR;
+  pwiz::msdata::SpectrumPtr spectrumPtr = Q_NULLPTR;
 
   // Counter of the effectively loaded spectra
   m_storedSpectraCount = 0;
