@@ -13,7 +13,7 @@
 
 using std::cout;
 
-#define TEST_DATA_DIR "/home/rusconi/devel/msxpertsuite/development/tests/data"
+#define TEST_DATA_DIR "/home/rusconi/devel/msxpertsuite/tests/data"
 
 //qDebug() << __FILE__ << __LINE__ << __FUNCTION__
 //<< "Should compile libmass tests.";
@@ -580,8 +580,7 @@ namespace msXpSlibmass
 	}
 
 
-	TEST_CASE("Combination of trace list into a mass "
-			"trace (non-binnable case).", "[Trace]")
+	TEST_CASE("Combination of trace list into a mass trace", "[Trace]")
 	{
 		// Preparation of various mobility-experiment data that are not binnable
 		// traces because the key intervals are not equal all along the key
@@ -599,8 +598,18 @@ namespace msXpSlibmass
 		int xyFormatStringListSize = xyFormatStringList.size();
 		QString xyFormatString = xyFormatStringList.join("\n");
 		Trace *massSpecIdx0 = new Trace;
-		massSpecIdx0->initialize(xyFormatString);
-		REQUIRE(xyFormatStringListSize == massSpecIdx0->size());
+		int count = massSpecIdx0->initialize(xyFormatString);
+
+		// Since the initialization is actually a combination of each DataPoint
+		// objects represented by each line, the 0-val DataPoint instances are not
+		// combined.
+
+		REQUIRE(count == 2);
+
+		//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+		//<< "Count is:" << count;
+
+		REQUIRE(massSpecIdx0->size() == 2);
 
 		xyFormatStringList.clear();
 		xyFormatStringList
@@ -613,7 +622,7 @@ namespace msXpSlibmass
 		xyFormatString = xyFormatStringList.join("\n");
 		Trace *massSpecIdx1 = new Trace;
 		massSpecIdx1->initialize(xyFormatString);
-		REQUIRE(xyFormatStringListSize == massSpecIdx1->size());
+		REQUIRE(massSpecIdx1->size() == 2);
 
 		xyFormatStringList.clear();
 		xyFormatStringList
@@ -626,7 +635,7 @@ namespace msXpSlibmass
 		xyFormatString = xyFormatStringList.join("\n");
 		Trace *massSpecIdx2 = new Trace;
 		massSpecIdx2->initialize(xyFormatString);
-		REQUIRE(xyFormatStringListSize == massSpecIdx2->size());
+		REQUIRE(massSpecIdx2->size() == 2);
 
 		xyFormatStringList.clear();
 		xyFormatStringList
@@ -638,7 +647,7 @@ namespace msXpSlibmass
 		xyFormatString = xyFormatStringList.join("\n");
 		Trace *massSpecIdx3 = new Trace;
 		massSpecIdx3->initialize(xyFormatString);
-		REQUIRE(xyFormatStringListSize == massSpecIdx3->size());
+		REQUIRE(massSpecIdx3->size() == 1);
 
 		xyFormatStringList.clear();
 		xyFormatStringList
@@ -655,12 +664,12 @@ namespace msXpSlibmass
 		xyFormatString = xyFormatStringList.join("\n");
 		Trace *massSpecIdx4 = new Trace;
 		massSpecIdx4->initialize(xyFormatString);
-		REQUIRE(xyFormatStringListSize == massSpecIdx4->size());
+		REQUIRE(massSpecIdx4->size() == 4);
 
 		xyFormatStringList.clear();
 
 
-		SECTION("Combination (not-binned case) with no key range.", "[Trace]")
+		SECTION("Combination with no key range", "[Trace]")
 		{
 			// We now have five traces. We can now construct the trace
 			// list.
@@ -699,7 +708,7 @@ namespace msXpSlibmass
 			xyFormatString = xyFormatStringList.join("\n");
 			Trace theorCombinedTrace;
 			theorCombinedTrace.initialize(xyFormatString);
-			REQUIRE(xyFormatStringListSize == theorCombinedTrace.size());
+			REQUIRE(theorCombinedTrace.size() == 11);
 
 			xyFormatStringList.clear();
 
@@ -708,6 +717,9 @@ namespace msXpSlibmass
 			Trace combinedTrace;
 			combinedTrace.combine(traces);
 
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				//<< "combinedTrace as text:" << combinedTrace.asText();
+
 			// Check that both the theor and the actual combined spectra have the same
 			// number of data point instances.
 
@@ -751,7 +763,8 @@ namespace msXpSlibmass
 			REQUIRE(failedComparisons == 0);
 		}
 
-		SECTION("Combine (not-binned case) with key range.", "[Trace]")
+
+		SECTION("Combine with key range", "[Trace]")
 		{
 			// We now have five traces. We can now construct the trace
 			// list.
@@ -761,37 +774,25 @@ namespace msXpSlibmass
 
 			// The un-key-ranged combination above provides the trace below
 			//
-			//"1848.9427702443 0.0000000000"
-			//"1848.9615803966 21.0000000000"
-			//"1848.9803905489 17.0000000000"
-			//"1848.9990785576 0.0000000000"
-			//"1861.6054557607 0.0000000000"
-			//"1861.6243881557 4.0000000000"
-			//"1861.6431984064 16.0000000000"
-			//"1861.6620086572 0.0000000000"
-			//"1879.3452969428 0.0000000000"
-			//"1879.3642294765 27.0000000000"
-			//"1879.3831620103 0.0000000000"
-			//"2007.9375013022 0.0000000000"
-			//"2007.9570456000 34.0000000000"
-			//"2007.9765898979 3.0000000000"
-			//"2007.9962563479 0.0000000000"
-			//"2173.2127519882 0.0000000000"
-			//"2173.2330305731 52.0000000000"
-			//"2173.2533091582 3.0000000000"
-			//"2173.2738320637 0.0000000000"
-			//"2207.9724474677 0.0000000000"
-			//"2207.9932149877 3.0000000000"
-			//"2208.0137381840 32.0000000000"
-			//"2208.0342613806 0.0000000000";
+			//1848.9615803966 21.0000000000
+			//1848.9803905489 17.0000000000
+			//1861.6243881557 4.0000000000
+			//1861.6431984064 16.0000000000
+			//1879.3642294765 27.0000000000
+			//2007.9570456000 34.0000000000
+			//2007.9765898979 3.0000000000
+			//2173.2330305731 52.0000000000
+			//2173.2533091582 3.0000000000
+			//2207.9932149877 3.0000000000
+			//2208.0137381840 32.0000000000
 
-			// Skip 5 spectra on the top (massSpecIdx0).
+			// Skip 3 spectra on the top (massSpecIdx0).
 			// A data point is in the range if key >= keyStart.
-			double keyStart = 1861.61;
+			double keyStart = 1861.63;
 
-			// Skip 5 spectra on the bottom
+			// Skip 3 spectra on the bottom
 			// A data point is in the range if key <= keyEnd.
-			double keyEnd = 2173.26;
+			double keyEnd = 2173.24;
 
 			//cout << std::setprecision(15) << "Combining spectra with key range: ["
 			//<< keyStart << "," << keyEnd << "]\n";
@@ -800,19 +801,11 @@ namespace msXpSlibmass
 
 			xyFormatStringList.clear();
 			xyFormatStringList
-				<< "1861.6243881557 4.0000000000"
-				<< "1861.6431984064 16.0000000000"
-				<< "1861.6620086572 0.0000000000"
-				<< "1879.3452969428 0.0000000000"
-				<< "1879.3642294765 27.0000000000"
-				<< "1879.3831620103 0.0000000000"
-				<< "2007.9375013022 0.0000000000"
-				<< "2007.9570456000 34.0000000000"
-				<< "2007.9765898979 3.0000000000"
-				<< "2007.9962563479 0.0000000000"
-				<< "2173.2127519882 0.0000000000"
-				<< "2173.2330305731 52.0000000000"
-				<< "2173.2533091582 3.0000000000";
+			<< "1861.6431984064 16.0000000000"
+			<< "1879.3642294765 27.0000000000"
+			<< "2007.9570456000 34.0000000000"
+			<< "2007.9765898979 3.0000000000"
+			<< "2173.2330305731 52.0000000000";
 
 			xyFormatStringListSize = xyFormatStringList.size();
 			xyFormatString = xyFormatStringList.join("\n");
@@ -871,7 +864,7 @@ namespace msXpSlibmass
 			REQUIRE(failedComparisons == 0);
 		}
 
-		SECTION("Combination (not-binned case) of keyList/valList.", "[Trace]")
+		SECTION("Combination of keyList/valList", "[Trace]")
 		{
 			// We now have five traces. We can now construct the trace
 			// list. Only use the first four, as the fifth will be combined in the form
@@ -909,29 +902,17 @@ namespace msXpSlibmass
 
 			xyFormatStringList.clear();
 			xyFormatStringList
-				<< "1848.9427702443 0.0000000000"
 				<< "1848.9615803966 21.0000000000"
 				<< "1848.9803905489 17.0000000000"
-				<< "1848.9990785576 0.0000000000"
-				<< "1861.6054557607 0.0000000000"
 				<< "1861.6243881557 4.0000000000"
 				<< "1861.6431984064 16.0000000000"
-				<< "1861.6620086572 0.0000000000"
-				<< "1879.3452969428 0.0000000000"
 				<< "1879.3642294765 27.0000000000"
-				<< "1879.3831620103 0.0000000000"
-				<< "2007.9375013022 0.0000000000"
 				<< "2007.9570456000 34.0000000000"
 				<< "2007.9765898979 3.0000000000"
-				<< "2007.9962563479 0.0000000000"
-				<< "2173.2127519882 0.0000000000"
 				<< "2173.2330305731 52.0000000000"
 				<< "2173.2533091582 3.0000000000"
-				<< "2173.2738320637 0.0000000000"
-				<< "2207.9724474677 0.0000000000"
 				<< "2207.9932149877 3.0000000000"
-				<< "2208.0137381840 32.0000000000"
-				<< "2208.0342613806 0.0000000000";
+				<< "2208.0137381840 32.0000000000";
 
 			xyFormatStringListSize = xyFormatStringList.size();
 			xyFormatString = xyFormatStringList.join("\n");
@@ -1046,7 +1027,7 @@ namespace msXpSlibmass
 			xyFormatString = xyFormatStringList.join("\n");
 			Trace theorCombinedTrace;
 			theorCombinedTrace.initialize(xyFormatString);
-			REQUIRE(xyFormatStringListSize == theorCombinedTrace.size());
+			REQUIRE(theorCombinedTrace.size() == 7);
 
 			xyFormatStringList.clear();
 
@@ -1293,13 +1274,11 @@ namespace msXpSlibmass
 		SECTION("Create a textual representation of a region of a mass "
 				"trace (without key range).", "[Trace]")
 		{
-			QString *text = trace.asText(-1, -1);
-			REQUIRE(text != Q_NULLPTR);
+			QString text = trace.asText(-1, -1);
+			REQUIRE(!text.isEmpty());
 
 			Trace reconstructedTrace;
-			reconstructedTrace.initialize(*text);
-
-			delete text;
+			reconstructedTrace.initialize(text);
 
 			REQUIRE(trace.size() == reconstructedTrace.size());
 
@@ -1351,13 +1330,11 @@ namespace msXpSlibmass
 			//<< "694.8349987789 879.0000000000" ;
 
 			// Skip the 5 top-most and bottom-most peaks.
-			QString *text = trace.asText(5, 14);
-			REQUIRE(text != Q_NULLPTR);
+			QString text = trace.asText(5, 14);
+			REQUIRE(!text.isEmpty());
 
 			Trace reconstructedTrace;
-			reconstructedTrace.initialize(*text);
-
-			delete text;
+			reconstructedTrace.initialize(text);
 
 			// The reconstructed trace has 10 peaks less than the original
 			// one.
@@ -1388,13 +1365,14 @@ namespace msXpSlibmass
 	// TEST_CASE("Various utility functions about traces.", "[Trace]")
 
 
-	TEST_CASE("Create trace from base64-encoded data in byte arrays.", "[Trace]")
+	TEST_CASE("Create trace from base64-encoded data in byte arrays", "[Trace]")
 	{
 		// Prepare the byte arrays from reading data from specific test files.
 
 		QFile key64File(QString("%1/base64/protein-mobility-waters-synapt-hdms.db-index-47-mzlist.base64")
 				.arg(TEST_DATA_DIR));
 		REQUIRE(key64File.open(QFile::ReadOnly));
+
 		QTextStream key64Stream(&key64File);
 		QByteArray key64ByteArray = key64Stream.readAll().toLatin1();
 		QByteArray keyDec64ByteArray = QByteArray::fromBase64(key64ByteArray);
@@ -1508,7 +1486,7 @@ namespace msXpSlibmass
 		REQUIRE(finalKeyArray.size() == finalIArray.size());
 
 		Trace trace;
-	 trace.initialize(&key64ByteArray, &i64ByteArray,
+		trace.initialize(&key64ByteArray, &i64ByteArray,
 				msXpS::DataCompression::DATA_COMPRESSION_ZLIB, 2000, 2400);
 
 		// This one contains both key and val lists in the xy format.
